==> nextcloud-23.0.3.tgz: nextcloud/apps/theming/l10n/el.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Φόρτωση προεπισκόπησης ...",
    "Saved" : "Αποθηκεύτηκαν",
    "Admin" : "Διαχειριστής",
    "a safe home for all your data" : "μια ασφαλής τοποθεσία για όλα σας τα δεδομένα",
    "Name cannot be empty" : "Το όνομα δεν μπορεί να είναι κενό",
    "The given name is too long" : "Το όνομα που δόθηκε είναι πολύ μεγάλο",
    "The given web address is too long" : "Η διεύθυνση ιστοσελίδας που δόθηκε είναι πολύ μεγάλη.",
    "The given web address is not a valid URL" : "Η διεύθυνση ιστοχώρου δεν είναι έγκυρη URL",
    "The given legal notice address is too long" : "Η διεύθυνση ειδοποίησης είναι πολύ μεγάλη",
    "The given legal notice address is not a valid URL" : "Η διεύθυνση νομικής ειδοποίησης δεν είναι έγκυρη διεύθυνση URL",
    "The given privacy policy address is too long" : "Η διεύθυνση πολιτικής απορρήτου είναι πολύ μεγάλη",
    "The given privacy policy address is not a valid URL" : "Η διεύθυνση πολιτικής απορρήτου δεν είναι έγκυρη διεύθυνση URL",
    "The given slogan is too long" : "Το ρητό που δόθηκε είναι πολύ μεγάλο",
    "The given color is invalid" : "Δόθηκε μη έγκυρο χρώμα",
    "The file was uploaded" : "Το αρχείο μεταφορτώθηκε",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία upload_max_filesize στο php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία MAX_FILE_SIZE που καθορίστηκε στην φόρμα HTML.",
    "The file was only partially uploaded" : "Το αρχείο μεταφορτώθηκε εν μέρει",
    "No file was uploaded" : "Δεν μεταφορτώθηκε κάποιο αρχείο",
    "Missing a temporary folder" : "Λείπει κάποιος προσωρινός φάκελος",
    "Could not write file to disk" : "Αδυναμία εγγραφής αρχείου στον δίσκο",
    "A PHP extension stopped the file upload" : "Ένα πρόσθετο PHP διέκοψε την μεταφόρτωση του αρχείου",
    "No file uploaded" : "Δεν έχει μεταφορτωθεί αρχείο",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Χρησιμοποιείτε ήδη προσαρμοσμένο θέμα. Οι ρυθμίσεις της εφαρμογής Θέματα μπορεί να αντικατασταθούν από αυτό.",
    "Theming" : "Προσαρμογή θέματος",
    "Legal notice" : "Νομική ειδοποίηση",
    "Privacy policy" : "Πολιτική Απορρήτου",
    "Adjust the Nextcloud theme" : "Προσαρμόστε το θέμα του Nextcloud",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Η προσαρμογή θέματος καθιστά δυνατή την εύκολη προσαρμογή της εμφάνισης της εμφάνισης της εγκατάστασής σας καθώς και των υποστηριζόμενων πελατών. Αυτή θα είναι ορατή για όλους τους χρήστες.",
    "Name" : "Όνομα",
    "Reset to default" : "Επαναφορά στα προεπιλεγμένα",
    "Web link" : "Σύνδεσμος ιστού",
    "https://…" : "https://…",
    "Slogan" : "Ρητό",
    "Color" : "Χρώμα",
    "Logo" : "Λογότυπο",
    "Upload new logo" : "Μεταφόρτωση νέου λογοτύπου",
    "Login image" : "Εικόνα εισόδου",
    "Upload new login background" : "Μεταφόρτωση νέου παρασκηνίου εισόδου",
    "Remove background image" : "Αφαίρεση εικόνας παρασκηνίου",
    "Advanced options" : "Επιλογές για προχωρημένους",
    "Legal notice link" : "Σύνδεσμος νομικής ειδοποίησης",
    "Privacy policy link" : "Σύνδεσμος πολιτικής απορρήτου",
    "Header logo" : "Λογότυπο επικεφαλίδας",
    "Upload new header logo" : "Μεταφόρτωση νέου λογοτύπου επικεφαλίδας",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Μεταφόρτωση νέου favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Εγκαταστήστε την επέκταση PHP Imagemagick με υποστήριξη SVG εικόνων, για να γίνει αυτόματη δημιουργία favicon βασισμένο πάνω στο μεταφορτωμένο λογότυπο και χρώμα."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/theming/l10n/el.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Φόρτωση προεπισκόπησης ...",
    "Admin" : "Διαχειριστής",
    "Saved" : "Αποθηκεύτηκαν",
    "a safe home for all your data" : "μια ασφαλής τοποθεσία για όλα σας τα δεδομένα",
    "Name cannot be empty" : "Το όνομα δεν μπορεί να είναι κενό",
    "The given name is too long" : "Το όνομα που δόθηκε είναι πολύ μεγάλο",
    "The given web address is too long" : "Η διεύθυνση ιστοσελίδας που δόθηκε είναι πολύ μεγάλη.",
    "The given web address is not a valid URL" : "Η διεύθυνση ιστοχώρου δεν είναι έγκυρη URL",
    "The given legal notice address is too long" : "Η διεύθυνση ειδοποίησης είναι πολύ μεγάλη",
    "The given legal notice address is not a valid URL" : "Η διεύθυνση νομικής ειδοποίησης δεν είναι έγκυρη διεύθυνση URL",
    "The given privacy policy address is too long" : "Η διεύθυνση πολιτικής απορρήτου είναι πολύ μεγάλη",
    "The given privacy policy address is not a valid URL" : "Η διεύθυνση πολιτικής απορρήτου δεν είναι έγκυρη διεύθυνση URL",
    "The given slogan is too long" : "Το ρητό που δόθηκε είναι πολύ μεγάλο",
    "The given color is invalid" : "Δόθηκε μη έγκυρο χρώμα",
    "The file was uploaded" : "Το αρχείο μεταφορτώθηκε",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία upload_max_filesize στο php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία MAX_FILE_SIZE που καθορίστηκε στην φόρμα HTML.",
    "The file was only partially uploaded" : "Το αρχείο μεταφορτώθηκε εν μέρει",
    "No file was uploaded" : "Δεν μεταφορτώθηκε κάποιο αρχείο",
    "Missing a temporary folder" : "Λείπει κάποιος προσωρινός φάκελος",
    "Could not write file to disk" : "Αδυναμία εγγραφής αρχείου στον δίσκο",
    "A PHP extension stopped the file upload" : "Ένα πρόσθετο PHP διέκοψε την μεταφόρτωση του αρχείου",
    "No file uploaded" : "Δεν έχει μεταφορτωθεί αρχείο",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Χρησιμοποιείτε ήδη προσαρμοσμένο θέμα. Οι ρυθμίσεις της εφαρμογής Θέματα μπορεί να αντικατασταθούν από αυτό.",
    "Theming" : "Προσαρμογή θέματος",
    "Dark theme" : "Σκούρο θέμα",
    "Enable dark theme" : "Ενεργοποίηση σκούρου θέματος",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "Enable dyslexia font" : "Ενεργοποίηση γραμματοσειράς για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη λάθη που προκαλεί η δυσλεξία στην ανάγνωση",
    "High contrast mode" : "Λειτουργία υψηλής αντίθεσης",
    "Enable high contrast mode" : "Ενεργοποίηση λειτουργίας υψηλής αντίθεσης",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Λειτουργία με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Legal notice" : "Νομική ειδοποίηση",
    "Privacy policy" : "Πολιτική Απορρήτου",
    "Adjust the Nextcloud theme" : "Προσαρμόστε το θέμα του Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Η  πρόσβαση  από όλους είναι πολύ σημαντική για εμάς. Ακολουθούμε τα πρότυπα του διαδικτύου και ελέγχουμε ότι τα πάντα μπορούν να χρησιμοποιηθούν χωρίς ποντίκι και βοηθητικό λογισμικό όπως προγράμματα ανάγνωσης οθόνης. Στόχος μας είναι να συμμορφωνόμαστε με τις {προδιαγραφές} Προδιαγραφές πρόσβασης περιεχομένου Ιστού 2.1 σε επίπεδο AA, με το θέμα υψηλής αντίθεσης ακόμη και σε επίπεδο ΑΑΑ.",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Η προσαρμογή θέματος καθιστά δυνατή την εύκολη προσαρμογή της εμφάνισης της εμφάνισης της εγκατάστασής σας καθώς και των υποστηριζόμενων πελατών. Αυτή θα είναι ορατή για όλους τους χρήστες.",
    "Name" : "Όνομα",
    "Reset to default" : "Επαναφορά στα προεπιλεγμένα",
    "Web link" : "Σύνδεσμος ιστού",
    "https://…" : "https://…",
    "Slogan" : "Ρητό",
    "Color" : "Χρώμα",
    "Logo" : "Λογότυπο",
    "Upload new logo" : "Μεταφόρτωση νέου λογοτύπου",
    "Login image" : "Εικόνα εισόδου",
    "Upload new login background" : "Μεταφόρτωση νέου παρασκηνίου εισόδου",
    "Remove background image" : "Αφαίρεση εικόνας παρασκηνίου",
    "Advanced options" : "Επιλογές για προχωρημένους",
    "Legal notice link" : "Σύνδεσμος νομικής ειδοποίησης",
    "Privacy policy link" : "Σύνδεσμος πολιτικής απορρήτου",
    "Header logo" : "Λογότυπο επικεφαλίδας",
    "Upload new header logo" : "Μεταφόρτωση νέου λογοτύπου επικεφαλίδας",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Μεταφόρτωση νέου favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Εγκαταστήστε την επέκταση PHP Imagemagick με υποστήριξη SVG εικόνων, για να γίνει αυτόματη δημιουργία favicon βασισμένο πάνω στο μεταφορτωμένο λογότυπο και χρώμα."
},
"nplurals=2; plural=(n != 1);");
